@@ -884,6 +884,8 @@ bool DebugSession::startDebugger(KDevelop::ILaunchConfiguration* cfg)
             &DebugSession::gdbUserCommandStdout);
     connect(gdb, &GDB::internalCommandOutput, this,
             &DebugSession::gdbInternalCommandStdout);
+    connect(gdb, &GDB::debuggerInternalOutput, this,
+            &DebugSession::gdbInternalOutput);
 
     connect(gdb, &GDB::ready, this, &DebugSession::gdbReady);
     connect(gdb, &GDB::gdbExited, this, &DebugSession::gdbExited);
@@ -950,6 +952,11 @@ bool DebugSession::startDebugger(KDevelop::ILaunchConfiguration* cfg)
         queueCmd(new GDBCommand(GDBMI::NonMI, "source " + fileName));
     }
 
+    if (m_testing) {
+        // GDB can't disable ASLR on CI server.
+        queueCmd(new GDBCommand(GDBMI::GdbSet, "disable-randomization off"));
+    }
+
     return true;
 }
 
