@@ -76,7 +76,7 @@ public:
     DisassembleWindow(QWidget *parent, DisassembleWidget* widget);
 
 protected:
-   virtual void contextMenuEvent(QContextMenuEvent *e) override;
+   void contextMenuEvent(QContextMenuEvent *e) override;
 
 private:
     QAction* m_selectAddrAction;
@@ -103,7 +103,7 @@ public:
     };
 
     DisassembleWidget( CppDebuggerPlugin* plugin, QWidget *parent=0 );
-    virtual ~DisassembleWidget();
+    ~DisassembleWidget() override;
 
 Q_SIGNALS:
     void requestRaise();
@@ -122,8 +122,8 @@ private Q_SLOTS:
     void currentSessionChanged(KDevelop::IDebugSession* session);
 
 protected:
-    virtual void showEvent(QShowEvent*) override;
-    virtual void hideEvent(QHideEvent*) override;
+    void showEvent(QShowEvent*) override;
+    void hideEvent(QHideEvent*) override;
     void enableControls(bool enabled);
 
 private:
