@@ -19,6 +19,8 @@
 #ifndef QTHELPNETWORK_H
 #define QTHELPNETWORK_H
 
+#include "debug.h"
+
 #include <QNetworkReply>
 #include <QTimer>
 #include <QHelpEngine>
@@ -48,6 +50,18 @@ HelpNetworkReply::HelpNetworkReply(const QNetworkRequest &request,
     setRequest(request);
     setOpenMode(QIODevice::ReadOnly);
 
+    // Instantly finish processing if data is empty. Without this code the loadFinished()
+    // signal will never be emitted by the corresponding QWebView.
+    if (!origLen) {
+        qCDebug(QTHELP) << "Empty data for" << request.url().toDisplayString();
+        QTimer::singleShot(0, this, SIGNAL(finished()));
+    }
+
+    // Fix broken CSS images (tested on Qt 5.5.1 and 5.7.0)
+    if (request.url().fileName() ==  QStringLiteral("offline.css")) {
+        data.replace("../images", "images");
+    }
+
     setHeader(QNetworkRequest::ContentTypeHeader, mimeType);
     setHeader(QNetworkRequest::ContentLengthHeader, QByteArray::number(origLen));
     QTimer::singleShot(0, this, SIGNAL(metaDataChanged()));
