@@ -1360,4 +1360,104 @@ void __builtin_ia32_pmovusdb512mem_mask(...);
 void __builtin_ia32_pmovusdw512mem_mask(...);
 void __builtin_ia32_pmovusqd512mem_mask(...);
 void __builtin_ia32_sfence(...);
+__m128d __builtin_ia32_cvtdq2pd(...);
+__m256d __builtin_ia32_cvtdq2pd256(...);
+__m128 __builtin_ia32_cvtdq2ps(...);
+__m256 __builtin_ia32_cvtdq2ps256(...);
+__m128d __builtin_ia32_cvtps2pd(...);
+__m256d __builtin_ia32_cvtps2pd256(...);
+void __builtin_ia32_movntdq(...);
+void __builtin_ia32_movntdq256(...);
+void __builtin_ia32_movntpd(...);
+void __builtin_ia32_movntpd256(...);
+void __builtin_ia32_movntps256(...);
+void __builtin_ia32_movntq(...);
+void __builtin_ia32_movntsd(...);
+__m512i  __builtin_ia32_paddb512_mask(...);
+__m128i  __builtin_ia32_paddd128_mask(...);
+__m256i  __builtin_ia32_paddd256_mask(...);
+__m128i  __builtin_ia32_paddq128_mask(...);
+__m256i  __builtin_ia32_paddq256_mask(...);
+__m128i  __builtin_ia32_pandd128_mask(...);
+__m256i  __builtin_ia32_pandd256_mask(...);
+__m128i  __builtin_ia32_pandnd128_mask(...);
+__m256i  __builtin_ia32_pandnd256_mask(...);
+__m128i  __builtin_ia32_pandnq128_mask(...);
+__m256i  __builtin_ia32_pandnq256_mask(...);
+int  __builtin_ia32_pmovmskb256(...);
+__m256i  __builtin_ia32_pmovsxbd256(...);
+__m256i  __builtin_ia32_pmovsxbq256(...);
+__m256i  __builtin_ia32_pmovsxbw256(...);
+__m256i  __builtin_ia32_pmovsxdq256(...);
+__m256i  __builtin_ia32_pmovsxwd256(...);
+__m256i  __builtin_ia32_pmovsxwq256(...);
+__m256i  __builtin_ia32_pmovzxbd256(...);
+__m256i  __builtin_ia32_pmovzxbq256(...);
+__m256i  __builtin_ia32_pmovzxbw256(...);
+__m256i  __builtin_ia32_pmovzxdq256(...);
+__m256i  __builtin_ia32_pmovzxwd256(...);
+__m256i  __builtin_ia32_pmovzxwq256(...);
+__m512i  __builtin_ia32_pmullw512_mask(...);
+__m128i  __builtin_ia32_pord128_mask(...);
+__m256i  __builtin_ia32_pord256_mask(...);
+__m128i  __builtin_ia32_porq128_mask(...);
+__m256i  __builtin_ia32_porq256_mask(...);
+__m128i  __builtin_ia32_prord128_mask(...);
+__m256i  __builtin_ia32_prord256_mask(...);
+__m512i  __builtin_ia32_psubb512_mask(...);
+__m128i  __builtin_ia32_psubq128_mask(...);
+__m256i  __builtin_ia32_psubq256_mask(...);
+__m128i  __builtin_ia32_pxord128_mask(...);
+__m256i  __builtin_ia32_pxord256_mask(...);
+__m128i  __builtin_ia32_pxorq128_mask(...);
+__m256i  __builtin_ia32_pxorq256_mask(...);
+__m256d __builtin_ia32_roundpd256(...);
+void __builtin_ia32_storedqu(...);
+void __builtin_ia32_storedqu256(...);
+void __builtin_ia32_storeupd(...);
+void __builtin_ia32_storeupd256(...);
+void __builtin_ia32_storeups(...);
+void __builtin_ia32_storeups256(...);
+__m128d  __builtin_ia32_andnpd128_mask(...);
+__m256d  __builtin_ia32_andnpd256_mask(...);
+__m512d  __builtin_ia32_andnpd512_mask(...);
+__m128  __builtin_ia32_andnps128_mask(...);
+__m256  __builtin_ia32_andnps256_mask(...);
+__m512  __builtin_ia32_andnps512_mask(...);
+__m512d  __builtin_ia32_andpd512_mask(...);
+__m512  __builtin_ia32_andps512_mask(...);
+__m128d  __builtin_ia32_orpd128_mask(...);
+__m256d  __builtin_ia32_orpd256_mask(...);
+__m512d  __builtin_ia32_orpd512_mask(...);
+__m128  __builtin_ia32_orps128_mask(...);
+__m256  __builtin_ia32_orps256_mask(...);
+__m512  __builtin_ia32_orps512_mask(...);
+__m128i  __builtin_ia32_paddb128_mask(...);
+__m256i  __builtin_ia32_paddb256_mask(...);
+__m128i  __builtin_ia32_paddsb128_mask(...);
+__m256i  __builtin_ia32_paddsb256_mask(...);
+__m128i  __builtin_ia32_paddsw128_mask(...);
+__m256i  __builtin_ia32_paddsw256_mask(...);
+__m512i  __builtin_ia32_paddsw512_mask(...);
+__m128i  __builtin_ia32_paddw128_mask(...);
+__m256i  __builtin_ia32_paddw256_mask(...);
+__m512i  __builtin_ia32_paddw512_mask(...);
+__m128i  __builtin_ia32_pmuldq128_mask(...);
+__m256i  __builtin_ia32_pmuldq256_mask(...);
+__m128i  __builtin_ia32_pmullq128_mask(...);
+__m256i  __builtin_ia32_pmullq256_mask(...);
+__m512i  __builtin_ia32_pmullq512_mask(...);
+__m128i  __builtin_ia32_pmullw128_mask(...);
+__m256i  __builtin_ia32_pmullw256_mask(...);
+__m512i  __builtin_ia32_prord512_mask(...);
+__m128i  __builtin_ia32_psubb128_mask(...);
+__m256i  __builtin_ia32_psubb256_mask(...);
+__m128i  __builtin_ia32_psubsb128_mask(...);
+__m256i  __builtin_ia32_psubsb256_mask(...);
+__m128d  __builtin_ia32_xorpd128_mask(...);
+__m256d  __builtin_ia32_xorpd256_mask(...);
+__m512d  __builtin_ia32_xorpd512_mask(...);
+__m128  __builtin_ia32_xorps128_mask(...);
+__m256  __builtin_ia32_xorps256_mask(...);
+__m512  __builtin_ia32_xorps512_mask(...);
 }
