@@ -25,11 +25,11 @@ namespace Cpp {
 
 MissingDeclarationProblem::MissingDeclarationProblem(Cpp::MissingDeclarationType::Ptr _type) : type(_type) {
   setDescription(i18n("Declaration not found: %1", type->identifier().toString()));
-  setSeverity(ProblemData::Hint);
+  setSeverity(IProblem::Warning);
 }
 
-KSharedPtr< KDevelop::IAssistant > Cpp::MissingDeclarationProblem::solutionAssistant() const {
-  return KSharedPtr< KDevelop::IAssistant >(new MissingDeclarationAssistant(KSharedPtr<MissingDeclarationProblem>(const_cast<MissingDeclarationProblem*>(this))));
+QExplicitlySharedDataPointer< KDevelop::IAssistant > Cpp::MissingDeclarationProblem::solutionAssistant() const {
+  return QExplicitlySharedDataPointer< KDevelop::IAssistant >(new MissingDeclarationAssistant(QExplicitlySharedDataPointer<MissingDeclarationProblem>(const_cast<MissingDeclarationProblem*>(this))));
 }
 
 }
